@@ -1,12 +1,12 @@
 #' Preview an email message
-#' @description Preview an HTML email before
-#' sending it out.
+#'
+#' Preview an HTML email in the Viewer
+#' before sending it out.
 #' @param email an \code{email_message} object.
 #' @importFrom htmltools html_print
-#' @export preview_email
-
+#' @export
 preview_email <- function(email) {
 
-  email[["html_html"]] %>% html_print()
+  email[["html_html"]] %>% htmltools::html_print()
 }
 
